#[non_exhaustive]pub struct EventOptions {
pub prepend: bool,
pub once: bool,
}Expand description
on()/on_waterfall() 注册选项(四偏差清单:prepend 保留,影响 serial/waterfall 结果)。
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.prepend: bool插到现有监听器之前(默认追加在后)。
once: boolClaim this registration at most once, when a dispatch selects its snapshot. A preceding short circuit can still skip its actual call.
Implementations
Sourceimpl EventOptions
impl EventOptions